@@ -22,19 +22,19 @@ class ClientTest(unittest.TestCase):
         self.assertIn({'identifier': 'MLKDream'}, result.docs)
 
     def test_get_item(self):
-        item = self.client.metadata('MLKDream')
+        item = self.client.getitem('MLKDream')
         self.assertEqual(item['metadata']['identifier'], 'MLKDream')
         self.assertEqual(item['files_count'], len(item['files']))
 
     def test_get_metadata(self):
-        metadata = self.client.metadata('MLKDream/metadata')
+        metadata = self.client.getitem('MLKDream/metadata')
         self.assertEqual(metadata['identifier'], 'MLKDream')
         self.assertRegexpMatches(metadata['creator'], 'Martin Luther King')
         self.assertRegexpMatches(metadata['title'], 'I Have a Dream')
         self.assertRegexpMatches(metadata['date'], '1963-08-28')
 
     def test_get_download_url(self):
-        for f in self.client.metadata('MLKDream/files'):
-            url = self.client.get_download_url('MLKDream', f['name'])
+        for f in self.client.getitem('MLKDream/files'):
+            url = self.client.geturl('MLKDream', f['name'])
             response = requests.head(url, allow_redirects=True)
             self.assertEqual(response.status_code, 200)
